NLSL: zaxpy.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

zaxpy.f90
Go to the documentation of this file.
1 c VC NLS VERSION 20 May 1992
2 c**********************************************************************
3 c
4 c complex double precision vector scale and add
5 c ---------------------------------------------
6 c
7 c This subroutine will update a complex double precision
8 c vector Y by the formula,
9 c
10 c Y=a*X+Y ,
11 c
12 c where a is a complex double precision constant and X is a
13 c complex double presion vector.
14 c
15 c Includes:
16 c nlsdim.inc
17 c rndoff.inc
18 c
19 c Uses:
20 c
21 c**********************************************************************
22 c
23 subroutine zaxpy(x,y,scale,ndim)
24 c
25 use nlsdim
26 c*djs use rnddbl
27 c
28 integer ndim
29 double complex scale
30 c
31 double complex x,y
32 dimension x(mxdim),y(mxdim)
33 c
34 integer iel
35 c
36 c*djs double complex CZERO
37 c*djs parameter (CZERO=(0.0D0,0.0D0))
38 c
39 c######################################################################
40 c
41 do iel=1,ndim
42 y(iel)=scale*x(iel)+y(iel)
43 c*djs if (abs(y(iel)).lt.rndoff) y(iel)=CZERO
44 end do
45 c
46 return
47 end
zaxpy
subroutine zaxpy(x, y, scale, ndim)
Definition: zaxpy.f90:24
nlsdim
Definition: nlsdim.f90:36
nlsdim::mxdim
integer, parameter mxdim
Definition: nlsdim.f90:39